@@ -3,10 +3,11 @@
 #' @param user `r template_var_user()`
 #' @param pass `r template_var_pass()`
 #' @param auth `r template_var_auth()`
+#' @param clean `r template_var_clean()`
 #'
 #' @concept actor
 #'
-#' @return a tibble of preferences
+#' @return a [tibble::tibble] of preferences
 #' @export
 #'
 #' @section Lexicon references:
@@ -18,7 +19,7 @@
 #' @examplesIf has_bluesky_pass() && has_bluesky_user()
 #' bs_get_preferences()
 bs_get_preferences <- function(user = get_bluesky_user(), pass = get_bluesky_pass(),
-                               auth = bs_auth(user, pass)) {
+                               auth = bs_auth(user, pass), clean = TRUE) {
 
   req <- httr2::request('https://bsky.social/xrpc/app.bsky.actor.getPreferences') |>
     httr2::req_auth_bearer_token(token = auth$accessJwt)
@@ -27,6 +28,8 @@ bs_get_preferences <- function(user = get_bluesky_user(), pass = get_bluesky_pas
     httr2::req_perform() |>
     httr2::resp_body_json()
 
+  if (!clean) return(resp)
+
   dplyr::bind_cols(
     resp$preferences[[1]] |> unlist() |> clean_names() |> tibble::as_tibble_row(),
     resp$preferences[[2]] |>
