@@ -3,6 +3,7 @@
 #' @param user `r template_var_user()`
 #' @param pass `r template_var_pass()`
 #' @param auth `r template_var_auth()`
+#' @param clean `r template_var_clean()`
 #'
 #' @concept notification
 #'
@@ -18,7 +19,7 @@
 #' @examplesIf has_bluesky_pass() & has_bluesky_user()
 #' bs_get_notification_count()
 bs_get_notification_count <- function(user = get_bluesky_user(), pass = get_bluesky_pass(),
-                                      auth = bs_auth(user, pass)) {
+                                      auth = bs_auth(user, pass), clean = TRUE) {
 
   req <- httr2::request('https://bsky.social/xrpc/app.bsky.notification.getUnreadCount') |>
     httr2::req_auth_bearer_token(token = auth$accessJwt)
@@ -27,6 +28,8 @@ bs_get_notification_count <- function(user = get_bluesky_user(), pass = get_blue
     httr2::req_perform() |>
     httr2::resp_body_json()
 
+  if (!clean) return(resp)
+
   resp |>
     tibble::as_tibble()
 }
